============
Installation
============

At the command line::

    $ pip install GEOparse

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv GEOparse
    $ pip install GEOparse

.. note::

    Not all dependencies will be installed automatically. The Biopython is only optional and it is used
    to interact with SRA entries. Please, install it if you are going to download SRA files.
